summaryrefslogtreecommitdiffstats
path: root/sys/boot/pc98/boot2
diff options
context:
space:
mode:
authorn_hibma <n_hibma@FreeBSD.org>2002-05-26 10:11:17 +0000
committern_hibma <n_hibma@FreeBSD.org>2002-05-26 10:11:17 +0000
commit6029daa1e0987efcbe7e707cd66a28dcca35a59e (patch)
treeaea0c736cfef269aa0666e000570771a0accecdf /sys/boot/pc98/boot2
parentcd78b1f556058950e6a372a22d8c2af37d07376e (diff)
downloadFreeBSD-src-6029daa1e0987efcbe7e707cd66a28dcca35a59e.zip
FreeBSD-src-6029daa1e0987efcbe7e707cd66a28dcca35a59e.tar.gz
Cosmetic change (align with other boot blocks):
CONSPEED -> COMSPEED Approved by: nyan
Diffstat (limited to 'sys/boot/pc98/boot2')
-rw-r--r--sys/boot/pc98/boot2/Makefile2
-rw-r--r--sys/boot/pc98/boot2/serial_16550.S8
2 files changed, 5 insertions, 5 deletions
diff --git a/sys/boot/pc98/boot2/Makefile b/sys/boot/pc98/boot2/Makefile
index ed44081..6077a09 100644
--- a/sys/boot/pc98/boot2/Makefile
+++ b/sys/boot/pc98/boot2/Makefile
@@ -27,7 +27,7 @@ CFLAGS+= -DCOMCONSOLE=${BOOT_COMCONSOLE_PORT} \
# feature not implemented
BOOT_COMCONSOLE_SPEED?=9600
-CFLAGS+= -DCONSPEED=${BOOT_COMCONSOLE_SPEED}
+CFLAGS+= -DCOMSPEED=${BOOT_COMCONSOLE_SPEED}
# Enable code to take the default boot string from a fixed location on the
# disk. See nextboot(8) and README.386BSD for more info.
diff --git a/sys/boot/pc98/boot2/serial_16550.S b/sys/boot/pc98/boot2/serial_16550.S
index 7512db4..114a369 100644
--- a/sys/boot/pc98/boot2/serial_16550.S
+++ b/sys/boot/pc98/boot2/serial_16550.S
@@ -80,7 +80,7 @@ WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
* BIOS support is duplicated here.
*
* The base address and speed for the i/o port are passed from the
* Makefile in the COMCONSOLE and CONSPEED preprocessor macros. The
* line control parameters are currently hard-coded to 8 bits, no
* parity, 1 stop bit (8N1). This can be changed in init_serial().
*/
@@ -143,7 +143,7 @@ ENTRY(serial_ischar)
/*
* void init_serial(void);
* Initialize port COMCONSOLE to speed CONSPEED, line settings 8N1.
*/
ENTRY(init_serial)
movl $COMCONSOLE + 3, %edx # line control reg
@@ -151,10 +151,10 @@ ENTRY(init_serial)
outb %al, %dx # enable DLAB
subl $3, %edx # divisor latch, low byte
- movb (1843200 / (16*(CONSPEED))) & 0xff, %al
+ movb (1843200 / (16*(COMSPEED))) & 0xff, %al
outb %al, %dx
incl %edx # divisor latch, high byte
- movb (1843200 / (16*(CONSPEED))) >> 8, %al
+ movb (1843200 / (16*(COMSPEED))) >> 8, %al
outb %al, %dx
incl %edx # fifo control register (if any)
OpenPOWER on IntegriCloud
@@ -80,7 +80,7 @@ WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*
* The base address and speed for the i/o port are passed from the
- * Makefile in the COMCONSOLE and CONSPEED preprocessor macros. The
+ * Makefile in the COMCONSOLE and COMSPEED preprocessor macros. The
* line control parameters are currently hard-coded to 8 bits, no
* parity, 1 stop bit (8N1). This can be changed in init_serial().
@@ -143,7 +143,7 @@ ENTRY(serial_ischar)
/*
* void init_serial(void);
- * Initialize port COMCONSOLE to speed CONSPEED, line settings 8N1.
+ * Initialize port COMCONSOLE to speed COMSPEED, line settings 8N1.
*/
ENTRY(init_serial)